@@ -66,8 +66,6 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
             "http": 3,
             "mq": 4,
             "cache": 5,
-            "log": 6,
-            "user": 7,
         }
 
     def _init_ip_and_port(self, collector):
@@ -130,7 +128,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         report_struct.parent_span_id = span.pid
         report_struct.span_id = span.sid
         report_struct.span_type = self.type_dict.get(span.kind.name, 3)
-        report_struct.span_layer = self.layer_dict.get(str(span.layer.name).lower(), 7)
+        report_struct.span_layer = self.layer_dict.get(str(span.layer.name).lower(), 10)
         report_struct.start_time = span.start_time
         report_struct.end_time = span.end_time
         report_struct.duration = span.end_time - span.start_time
