@@ -55,7 +55,9 @@ class FastTrackerConfiger:
                         if config_key in default_config_keys:
                             func_name = "set_" + functions.lower_case_name(config_key)
                             # 如果环境变量已经有值，则不再赋值
-                            config_name = func_name if func_name != "socket_path" else "collector_address"
+                            config_name = (
+                                "FastTracker_" + config_key if config_key != "SocketPath" else "CollectorAddress"
+                            )
                             is_exist = os.getenv(config_name, "None")
                             if is_exist == "None":
                                 getattr(config, func_name)(config_dict.get(config_key))
